@@ -273,7 +273,7 @@ def make_cloud(object_list, count_attribute, steps=5):
 def moneyformat(value, decimal_places=2, thousands_separator=''):
     """Returns a float value in monetary format, using MONETARY_LOCALE
     setting and locale functions"""
-    decimal_places = decimal_places or 2
+    decimal_places = decimal_places is None and 2 or decimal_places
     thousands_separator = thousands_separator or app_settings.THOUSANDS_SEPARATOR
 
     import locale
@@ -290,7 +290,10 @@ def moneyformat(value, decimal_places=2, thousands_separator=''):
     if thousands_separator:
         dec_sep = thousands_separator == ',' and '.' or ','
         parts = ret.split(dec_sep)
-        ret = split1000(parts[0].replace(thousands_separator, ''), thousands_separator) + dec_sep + parts[1]
+        ret = split1000(parts[0].replace(thousands_separator, ''), thousands_separator)
+
+        if len(parts) > 1:
+            ret += dec_sep + parts[1]
 
     return ret
 
