@@ -21,6 +21,12 @@ def get_admin_url(obj):
     from django.contrib import admin
     admin_root_path = admin.site.root_path
 
+    # Try method 'get_admin_url' before use ordinary way
+    try:
+        return getattr(obj, 'get_admin_url')()
+    except AttributeError:
+        pass
+
     return '%s%s/%s/%s/'%(
             admin_root_path,
             obj._meta.app_label,
