@@ -106,10 +106,10 @@ class AjaxFKWidget(TextInput):
                 "load-url": self.load_url,
                 "add-url": self.add_url,
                 "fill-left-zeros": self.fill_left_zeros,
-                "callback-funcion-on-change": '', # JavaScript function name to call after
-                                                  # change the widget value. This function
-                                                  # must waits for a param to receive the
-                                                  # JSON of changed values
+                "callback-function-on-change": '', # JavaScript function name to call after
+                                                   # change the widget value. This function
+                                                   # must waits for a param to receive the
+                                                   # JSON of changed values
                 }
 
         # Loads extra parameters from its driver
@@ -133,8 +133,11 @@ class AjaxFKWidget(TextInput):
         return ''
 
     def label_for_value(self, value):
-        obj = self.model._default_manager.get(**{self.related_field: value})
-        return unicode(obj)
+        try:
+            obj = self.model._default_manager.get(**{self.related_field: value})
+            return unicode(obj)
+        except self.model.DoesNotExist:
+            return ''
 
     def get_display_url(self, value):
         global registered_models
